<?php
/**
 * Tafri Travel functions and definitions
 *
 * @package tafri-travel
 */
/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */
if (!function_exists('tafri_travel_setup')):

function tafri_travel_setup() {

	$GLOBALS['content_width'] = apply_filters('tafri_travel_content_width', 640);

	add_theme_support('automatic-feed-links');
	add_theme_support('post-thumbnails');
	add_theme_support('woocommerce');
	add_theme_support('title-tag');
	add_theme_support('custom-logo', array(
		'height'      => 250,
		'width'       => 250,
		'flex-width'  => true,
		'flex-height' => true,
	));
	add_image_size('tafri-travel-homepage-thumb', 250, 145, true);
	register_nav_menus( array(
		'left-primary' => __( 'Left Menu', 'tafri-travel' ),
		'right-primary' => __( 'Right Menu', 'tafri-travel' ),
		'responsive-menu' => __( 'Responsive Menu', 'tafri-travel' ),
	) );
	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );
	
	add_theme_support('custom-background', array(
		'default-color' => 'f1f1f1',
	));

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style(array('assets/css/editor-style.css', tafri_travel_font_url()));
}

endif;
add_action('after_setup_theme', 'tafri_travel_setup');

// Theme Widgets Setup
function tafri_travel_widgets_init() {
	register_sidebar(array(
		'name'          => __('Blog Sidebar', 'tafri-travel'),
		'description'   => __('Appears on blog page sidebar', 'tafri-travel'),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));

	register_sidebar(array(
		'name'          => __('Page Sidebar', 'tafri-travel'),
		'description'   => __('Appears on page sidebar', 'tafri-travel'),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));

	register_sidebar(array(
		'name'          => __('Third Column Sidebar', 'tafri-travel'),
		'description'   => __('Appears on page sidebar', 'tafri-travel'),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));

	register_sidebar(array(
		'name'          => __('Footer Navigation 1', 'tafri-travel'),
		'description'   => __('Appears on footer', 'tafri-travel'),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));

	register_sidebar(array(
		'name'          => __('Footer Navigation 2', 'tafri-travel'),
		'description'   => __('Appears on footer', 'tafri-travel'),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));

	register_sidebar(array(
		'name'          => __('Footer Navigation 3', 'tafri-travel'),
		'description'   => __('Appears on footer', 'tafri-travel'),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));

	register_sidebar(array(
		'name'          => __('Footer Navigation 4', 'tafri-travel'),
		'description'   => __('Appears on footer', 'tafri-travel'),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
}

add_action('widgets_init', 'tafri_travel_widgets_init');

/* Theme Font URL */
function tafri_travel_font_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i';
	$font_family[] = 'Merienda One';
	$font_family[] = 'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'B612:400,400i,700,700i';
	$font_family[] = 'Kalam:300,400,700';
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';
	$font_family[] = 'Roboto Condensed:400,700';
	$font_family[] = 'Open Sans';
	$font_family[] = 'Overpass';
	$font_family[] = 'Montserrat:300,400,600,700,800,900';
	$font_family[] = 'Playball:300,400,600,700,800,900';
	$font_family[] = 'Alegreya:300,400,600,700,800,900';
	$font_family[] = 'Julius Sans One';
	$font_family[] = 'Arsenal';
	$font_family[] = 'Slabo';
	$font_family[] = 'Lato';
	$font_family[] = 'Overpass Mono';
	$font_family[] = 'Source Sans Pro';
	$font_family[] = 'Raleway';
	$font_family[] = 'Merriweather';
	$font_family[] = 'Droid Sans';
	$font_family[] = 'Rubik';
	$font_family[] = 'Lora';
	$font_family[] = 'Ubuntu';
	$font_family[] = 'Cabin';
	$font_family[] = 'Arimo';
	$font_family[] = 'Playfair Display';
	$font_family[] = 'Quicksand';
	$font_family[] = 'Padauk';
	$font_family[] = 'Muli';
	$font_family[] = 'Inconsolata';
	$font_family[] = 'Bitter';
	$font_family[] = 'Pacifico';
	$font_family[] = 'Indie Flower';
	$font_family[] = 'VT323';
	$font_family[] = 'Dosis';
	$font_family[] = 'Frank Ruhl Libre';
	$font_family[] = 'Fjalla One';
	$font_family[] = 'Oxygen';
	$font_family[] = 'Arvo';
	$font_family[] = 'Noto Serif';
	$font_family[] = 'Lobster';
	$font_family[] = 'Crimson Text';
	$font_family[] = 'Yanone Kaffeesatz';
	$font_family[] = 'Anton';
	$font_family[] = 'Libre Baskerville';
	$font_family[] = 'Bree Serif';
	$font_family[] = 'Gloria Hallelujah';
	$font_family[] = 'Josefin Sans';
	$font_family[] = 'Abril Fatface';
	$font_family[] = 'Varela Round';
	$font_family[] = 'Vampiro One';
	$font_family[] = 'Shadows Into Light';
	$font_family[] = 'Cuprum';
	$font_family[] = 'Rokkitt';
	$font_family[] = 'Vollkorn';
	$font_family[] = 'Francois One';
	$font_family[] = 'Orbitron';
	$font_family[] = 'Patua One';
	$font_family[] = 'Acme';
	$font_family[] = 'Satisfy';
	$font_family[] = 'Josefin Slab';
	$font_family[] = 'Quattrocento Sans';
	$font_family[] = 'Architects Daughter';
	$font_family[] = 'Russo One';
	$font_family[] = 'Monda';
	$font_family[] = 'Righteous';
	$font_family[] = 'Lobster Two';
	$font_family[] = 'Hammersmith One';
	$font_family[] = 'Courgette';
	$font_family[] = 'Permanent Marker';
	$font_family[] = 'Cherry Swash';
	$font_family[] = 'Cormorant Garamond';
	$font_family[] = 'Poiret One';
	$font_family[] = 'BenchNine';
	$font_family[] = 'Economica';
	$font_family[] = 'Handlee';
	$font_family[] = 'Cardo';
	$font_family[] = 'Alfa Slab One';
	$font_family[] = 'Averia Serif Libre';
	$font_family[] = 'Cookie';
	$font_family[] = 'Chewy';
	$font_family[] = 'Great Vibes';
	$font_family[] = 'Coming Soon';
	$font_family[] = 'Philosopher';
	$font_family[] = 'Days One';
	$font_family[] = 'Kanit';
	$font_family[] = 'Shrikhand';
	$font_family[] = 'Tangerine';
	$font_family[] = 'IM Fell English SC';
	$font_family[] = 'Boogaloo';
	$font_family[] = 'Bangers';
	$font_family[] = 'Fredoka One';
	$font_family[] = 'Bad Script';
	$font_family[] = 'Volkhov';
	$font_family[] = 'Shadows Into Light Two';
	$font_family[] = 'Marck Script';
	$font_family[] = 'Sacramento';
	$font_family[] = 'Unica One';
	$font_family[] = 'Noto Sans:400,400i,700,700i';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

function tafri_travel_sanitize_dropdown_pages($page_id, $setting) {
	// Ensure $input is an absolute integer.
	$page_id = absint($page_id);
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ('publish' == get_post_status($page_id)?$page_id:$setting->default);
}

// radio button sanitization
function tafri_travel_sanitize_choices($input, $setting) {
	global $wp_customize;
	$control = $wp_customize->get_control($setting->id);
	if (array_key_exists($input, $control->choices)) {
		return $input;
	} else {
		return $setting->default;
	}
}

// Excerpt Limit Begin
function tafri_travel_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'tafri_travel_loop_columns');
	if (!function_exists('tafri_travel_loop_columns')) {
		function tafri_travel_loop_columns() {
		return 3; // 3 products per row
	}
}

// Theme enqueue scripts
function tafri_travel_scripts() {
	wp_enqueue_style('tafri-travel-font', tafri_travel_font_url(), array());
	wp_enqueue_style('bootstrap', get_template_directory_uri().'/assets/css/bootstrap.css');
	wp_enqueue_style('tafri-travel-basic-style', get_stylesheet_uri());
	wp_enqueue_style('tafri-travel-customcss', get_template_directory_uri().'/assets/css/custom.css');
	wp_enqueue_style('font-awesome', get_template_directory_uri().'/assets/css/fontawesome-all.css');

	// Paragraph
	    $tafri_travel_paragraph_color = get_theme_mod('tafri_travel_paragraph_color', '');
	    $tafri_travel_paragraph_font_family = get_theme_mod('tafri_travel_paragraph_font_family', '');
	    $tafri_travel_paragraph_font_size = get_theme_mod('tafri_travel_paragraph_font_size', '');
	// "a" tag
		$tafri_travel_atag_color = get_theme_mod('tafri_travel_atag_color', '');
	    $tafri_travel_atag_font_family = get_theme_mod('tafri_travel_atag_font_family', '');
	// "li" tag
		$tafri_travel_li_color = get_theme_mod('tafri_travel_li_color', '');
	    $tafri_travel_li_font_family = get_theme_mod('tafri_travel_li_font_family', '');
	// H1
		$tafri_travel_h1_color = get_theme_mod('tafri_travel_h1_color', '');
	    $tafri_travel_h1_font_family = get_theme_mod('tafri_travel_h1_font_family', '');
	    $tafri_travel_h1_font_size = get_theme_mod('tafri_travel_h1_font_size', '');
	// H2
		$tafri_travel_h2_color = get_theme_mod('tafri_travel_h2_color', '');
	    $tafri_travel_h2_font_family = get_theme_mod('tafri_travel_h2_font_family', '');
	    $tafri_travel_h2_font_size = get_theme_mod('tafri_travel_h2_font_size', '');
	// H3
		$tafri_travel_h3_color = get_theme_mod('tafri_travel_h3_color', '');
	    $tafri_travel_h3_font_family = get_theme_mod('tafri_travel_h3_font_family', '');
	    $tafri_travel_h3_font_size = get_theme_mod('tafri_travel_h3_font_size', '');
	// H4
		$tafri_travel_h4_color = get_theme_mod('tafri_travel_h4_color', '');
	    $tafri_travel_h4_font_family = get_theme_mod('tafri_travel_h4_font_family', '');
	    $tafri_travel_h4_font_size = get_theme_mod('tafri_travel_h4_font_size', '');
	// H5
		$tafri_travel_h5_color = get_theme_mod('tafri_travel_h5_color', '');
	    $tafri_travel_h5_font_family = get_theme_mod('tafri_travel_h5_font_family', '');
	    $tafri_travel_h5_font_size = get_theme_mod('tafri_travel_h5_font_size', '');
	// H6
		$tafri_travel_h6_color = get_theme_mod('tafri_travel_h6_color', '');
	    $tafri_travel_h6_font_family = get_theme_mod('tafri_travel_h6_font_family', '');
	    $tafri_travel_h6_font_size = get_theme_mod('tafri_travel_h6_font_size', '');

		$custom_css ='
			p,span{
			    color:'.esc_html($tafri_travel_paragraph_color).'!important;
			    font-family: '.esc_html($tafri_travel_paragraph_font_family).';
			    font-size: '.esc_html($tafri_travel_paragraph_font_size).';
			}
			a{
			    color:'.esc_html($tafri_travel_atag_color).'!important;
			    font-family: '.esc_html($tafri_travel_atag_font_family).';
			}
			li{
			    color:'.esc_html($tafri_travel_li_color).'!important;
			    font-family: '.esc_html($tafri_travel_li_font_family).';
			}
			h1{
			    color:'.esc_html($tafri_travel_h1_color).'!important;
			    font-family: '.esc_html($tafri_travel_h1_font_family).'!important;
			    font-size: '.esc_html($tafri_travel_h1_font_size).'!important;
			}
			h2{
			    color:'.esc_html($tafri_travel_h2_color).'!important;
			    font-family: '.esc_html($tafri_travel_h2_font_family).'!important;
			    font-size: '.esc_html($tafri_travel_h2_font_size).'!important;
			}
			h3{
			    color:'.esc_html($tafri_travel_h3_color).'!important;
			    font-family: '.esc_html($tafri_travel_h3_font_family).'!important;
			    font-size: '.esc_html($tafri_travel_h3_font_size).'!important;
			}
			h4{
			    color:'.esc_html($tafri_travel_h4_color).'!important;
			    font-family: '.esc_html($tafri_travel_h4_font_family).'!important;
			    font-size: '.esc_html($tafri_travel_h4_font_size).'!important;
			}
			h5{
			    color:'.esc_html($tafri_travel_h5_color).'!important;
			    font-family: '.esc_html($tafri_travel_h5_font_family).'!important;
			    font-size: '.esc_html($tafri_travel_h5_font_size).'!important;
			}
			h6{
			    color:'.esc_html($tafri_travel_h6_color).'!important;
			    font-family: '.esc_html($tafri_travel_h6_font_family).'!important;
			    font-size: '.esc_html($tafri_travel_h6_font_size).'!important;
			}
			';

	wp_add_inline_style( 'tafri-travel-basic-style',$custom_css );

	wp_enqueue_script('SmoothScroll', get_template_directory_uri().'/assets/js/SmoothScroll.js', array('jquery'));
	wp_enqueue_script('tafri-travel-customscripts-jquery', get_template_directory_uri().'/assets/js/custom.js', array('jquery'));
	wp_enqueue_script('bootstrap', get_template_directory_uri().'/assets/js/bootstrap.js', array('jquery'));
	wp_enqueue_script( 'jquery-superfish', get_template_directory_uri() . '/assets/js/jquery.superfish.js', array('jquery') ,'',true);
	require get_parent_theme_file_path( '/color-option.php' );
	wp_add_inline_style( 'tafri-travel-basic-style',$custom_css );
	wp_enqueue_style('tafri-travel-ie', get_template_directory_uri().'/assets/css/ie.css', array('tafri-travel-basic-style'));
	wp_style_add_data('tafri-travel-ie', 'conditional', 'IE');
	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'tafri_travel_scripts');

define('TAFRI_TRAVEL_LIVE_DEMO','https://www.themeseye.com/demo/tafri-travel-pro/','tafri-travel');
define('TAFRI_TRAVEL_BUY_PRO','https://www.themeseye.com/wordpress/wordpress-travel-theme/','tafri-travel');
define('TAFRI_TRAVEL_PRO_DOC','https://themeseye.com/theme-demo/docs/tafri-travel-pro/','tafri-travel');
define('TAFRI_TRAVEL_FREE_DOC','https://themeseye.com/theme-demo/docs/free-tafri-travel/','tafri-travel');
define('TAFRI_TRAVEL_PRO_SUPPORT','https://www.themeseye.com/forums/forum/themeseye-support/','tafri-travel');
define('TAFRI_TRAVEL_FREE_SUPPORT','https://wordpress.org/support/theme/tafri-travel/','tafri-travel');
define('TAFRI_TRAVEL_CREDIT','https://www.themeseye.com/wordpress/free-wordpress-travel-theme/','tafri-travel');

if ( ! function_exists( 'tafri_travel_credit' ) ) {
	function tafri_travel_credit(){
		echo "<a href=".esc_url(TAFRI_TRAVEL_CREDIT).">".esc_html__('Travel WordPress Theme','tafri-travel')."</a>";
	}
}

/* Custom header additions. */
require get_template_directory().'/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory().'/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory().'/inc/customizer.php';

require get_parent_theme_file_path( '/inc/dashboard/get_started_info.php' ); 